@@ -26,4 +26,9 @@ class UTF8JSONField(JSONField):
     """
 
     def formfield(self, **kwargs):
-        return super().formfield(**{**{'form_class': UTF8JSONFormField}, **kwargs,})
+        return super().formfield(
+            **{
+                **{'form_class': UTF8JSONFormField},
+                **kwargs,
+            }
+        )
