@@ -19,7 +19,7 @@ class BaseCredentialMixin(object):
         url = settings.DASHBOARD_URL + '/'
 
     if hasattr(settings, 'IS_BOX_APP') and settings.IS_BOX_APP:
-        url = f'{settings.DASHBOARD_URL}auth-new/me'
+        url = f'{settings.AUTH_URL}'
         header_param = 'Authorization'
     else:
         url = f'{url}api/check-platform/'
