@@ -67,7 +67,14 @@ def get_smart_token(platform: str) -> str:
     :return: str
     """
     if hasattr(settings, 'IS_BOX_APP') and settings.IS_BOX_APP:
-        return settings.AUTH_TOKEN
+        r = requests.post(
+            settings.AUTH_TOKEN_URL,
+            json={
+                'username': settings.ADMIN_USERNAME,
+                'password': settings.ADMIN_USER_PASSWORD,
+            },
+        ).json()
+        return r['access']['value']
     else:
         url = f'{DASHBOARD_URL}api/smart_tokens/?platform_id={platform}'
         token = settings.EXECUTE_TOKEN
