@@ -29,12 +29,12 @@ REGEX_PATTERN_VALUES = [
     '<=',
     '=^',
     '!^',
-    '=\^',
-    '!\^',
+    '=\\^',
+    '!\\^',
     '=$',
     '!$',
-    '=\$',
-    '!\$',
+    '=\\$',
+    '!\\$',
     '=~',
     '!~',
     '!=',
@@ -49,12 +49,12 @@ REGEX_PATTERN_VALUES = [
     '=~',
     '!^',
     '=^',
-    '!\^',
-    '=\^',
+    '!\\^',
+    '=\\^',
     '!$',
     '=$',
-    '!\$',
-    '=\$',
+    '!\\$',
+    '=\\$',
     'undefined',
     '\n',
     '\t',
@@ -79,7 +79,7 @@ def remove_unacceptable_chars(
     value: Optional[str],
     pattern_values: list = REGEX_PATTERN_VALUES,
     default_value: Optional[str] = 'none',
-) -> str:
+) -> Optional[str]:
     pattern = r'|'.join(f'{v}' for v in pattern_values)
     if value is None or value == '':
         return default_value
@@ -132,7 +132,7 @@ def calc(s: str) -> str:
     :param s: str (value like ('(1 * 2) / 3'))
     :return: str (result of math operation)
     """
-    val = s.group()
+    val = s.group()  # type: ignore
     if not val.strip():
         return val
     return "%s" % eval(val.strip(), {'__builtins__': None})
@@ -143,7 +143,7 @@ def calculate(s: str) -> str:
     :param s: str
     :return: str
     """
-    return re.sub(r"([0-9\ \.\+\*\-\/(\)]+)", calc, s)
+    return re.sub(r"([0-9\ \.\+\*\-\/(\)]+)", calc, s)  # type: ignore
 
 
 def replacer(string: str, name: str, value: Any) -> str:
@@ -166,4 +166,3 @@ def remove_tags(text: str) -> str:
     """
     TAG_RE = re.compile(r'<[^>]+>')
     return TAG_RE.sub('', text)
-
